% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MergeRefToExp.R
\name{MergeRefToExp}
\alias{MergeRefToExp}
\title{Merge a Reference To Experiments}
\usage{
MergeRefToExp(
  data1,
  data2,
  dates1 = NULL,
  dates2 = NULL,
  start1 = NULL,
  end1 = NULL,
  start2 = NULL,
  end2 = NULL,
  time_dim = "ftime",
  memb_dim = "member",
  ncores = NULL
)
}
\arguments{
\item{data1}{A multidimensional array of with named dimensions matching the
dimensions of parameter 'data2'. Dimensions with the same name in the 
'data2' parameter must have the same length or length 1; except for the 
dimension specified with 'memb_dim', which can be different and in the 
result will be filled with NA values. It can also have additional dimensions 
with different names in 'data2'.}

\item{data2}{A multidimensional array of dates with named dimensions matching 
the dimensions on parameter 'data1'. Dimensions with the same name in the 
'data1' parameter must have the same length or length 1, except for the 
dimension specified with 'memb_dim', which can be different and in the 
result will be filled with NA values.}

\item{dates1}{A multidimensional array of dates with named dimensions matching 
the temporal dimensions on parameter 'data1'.}

\item{dates2}{A multidimensional array of dates with named dimensions matching 
the temporal dimensions on parameter 'data2'.}

\item{start1}{A list to define the initial date of the period to select from 
data1 by providing a list of two elements: the initial date of the period 
and the initial month of the period.}

\item{end1}{A list to define the final date of the period to select from 
data1 by providing a list of two elements: the final day of the period and 
the final month of the period.}

\item{start2}{A list to define the initial date of the period to select from 
data2 by providing a list of two elements: the initial date of the period 
and the initial month of the period.}

\item{end2}{A list to define the final date of the period to select from 
data2 by providing a list of two elements: the final day of the period and 
the final month of the period.}

\item{time_dim}{A character string indicating the name of the temporal 
dimension. By default, it is set to 'ftime'. More than one dimension name 
matching the dimensions provided in the object \code{data$data} can be 
specified. This dimension is required to subset the data in a requested 
period.}

\item{memb_dim}{A character string indicating the name of the member 
dimension. If the data are not ensemble ones, set as NULL. The default 
value is 'member'.}

\item{ncores}{An integer indicating the number of cores to use in parallel 
computation.}
}
\value{
A multidimensional array with dimensions named from the combination of 
'data1' and 'data2'. The resulting dimensions will be the following: all the 
same common dimensions between the two arrays plus the different dimensions of 
each array. If there is any different common dimension but in a dataset it has 
length 1, it will be added with the maximum dimension. If memb_dim is used, 
the dimension of the maximum value corresponding to memb_dim of the two data 
sets will be added; the difference between the dimensions of the set members 
will be filled with NA.
}
\description{
Some indicators are defined for specific temporal periods (e.g.: summer from 
June 21st to September 21st). If the initialization forecast date is later 
than the one required for the indicator (e.g.: July 1st), the user may want to 
merge past observations, or other reference, to the forecast (or hindcast) to 
compute the indicator. The function \code{MergeObs2Exp} takes care of this 
steps. If the forecast simulation doesn't cover the required period because it 
is initialized too early (e.g.: Initialization on November 1st the forecast 
covers until the beginning of June next year), a climatology (or other 
references) could be added at the end of the forecast lead time to cover the 
desired period (e.g.: until the end of summer).
}
\examples{
data_dates <- c(seq(as.Date("01-07-1993", "\%d-\%m-\%Y", tz = 'UTC'),
                   as.Date("01-12-1993","\%d-\%m-\%Y", tz = 'UTC'), "day"),
               seq(as.Date("01-07-1994", "\%d-\%m-\%Y", tz = 'UTC'),
                   as.Date("01-12-1994","\%d-\%m-\%Y", tz = 'UTC'), "day"))
dim(data_dates) <- c(ftime = 154, sdate = 2)
ref_dates <- seq(as.Date("01-01-1993", "\%d-\%m-\%Y", tz = 'UTC'),
                as.Date("01-12-1994","\%d-\%m-\%Y", tz = 'UTC'), "day")
dim(ref_dates) <- c(ftime = 350, sdate = 2)
ref <- array(1001:1700, c(ftime = 350, sdate = 2))
data <- array(1:(2*154*2), c(ftime = 154, sdate = 2, member = 2))
new_data <- MergeRefToExp(data1 = ref, dates1 = ref_dates, start1 = list(21, 6),
                         end1 = list(30, 6), data2 = data, dates2 = data_dates,
                         start2 = list(1, 7), end = list(21, 9), 
                         time_dim = 'ftime')

}
